@@ -21,7 +21,7 @@
  *      misrepresented as being the original software.
  *  3.  This notice may not be removed or altered from any source distribution.
  *
- *  Version: $Id: embryo_cc_sc2.c 44057 2009-11-30 18:08:33Z caro $
+ *  Version: $Id: embryo_cc_sc2.c 45428 2010-01-22 06:37:19Z caro $
  */
 
 /*
@@ -38,7 +38,6 @@
 #include <string.h>
 #include <ctype.h>
 #include <math.h>
-#include "embryo_cc_osdefs.h"
 #include "embryo_cc_sc.h"
 #include "Embryo.h"
 
@@ -117,14 +116,10 @@ plungequalifiedfile(char *name)
    pushstk((stkitem) inpf);
    pushstk((stkitem) inpfname);	/* pointer to current file name */
    pushstk((stkitem) curlibrary);
-   /* FIXME: 64bit unsafe */
    pushstk((stkitem) iflevel);
    assert(skiplevel == 0);
-   /* FIXME: 64bit unsafe */
    pushstk((stkitem) icomment);
-   /* FIXME: 64bit unsafe */
    pushstk((stkitem) fcurrent);
-   /* FIXME: 64bit unsafe */
    pushstk((stkitem) fline);
    inpfname = strdup(name);	/* set name of include file */
    if (inpfname == NULL)
@@ -154,7 +149,7 @@ plungefile(char *name, int try_currentpath, int try_includepaths)
      {
 	for (i = 0; !result && (ptr = get_path(i)) != NULL; i++)
 	  {
-	     char                path[_MAX_PATH];
+	     char                path[PATH_MAX];
 
 	     strncpy(path, ptr, sizeof path);
 	     path[sizeof path - 1] = '\0';	/* force '\0' termination */
@@ -190,7 +185,7 @@ check_empty(char *lptr)
 static void
 doinclude(void)
 {
-   char                name[_MAX_PATH], c;
+   char                name[PATH_MAX], c;
    int                 i, result;
 
    while (*lptr <= ' ' && *lptr != 0)	/* skip leading whitespace */
@@ -933,7 +928,7 @@ command(void)
      case tpFILE:
 	if (skiplevel == 0)
 	  {
-	     char                pathname[_MAX_PATH];
+	     char                pathname[PATH_MAX];
 
 	     lptr = getstring(pathname, sizeof pathname, lptr);
 	     if (pathname[0] != '\0')
