@@ -18,7 +18,7 @@
  *      misrepresented as being the original software.
  *  3.  This notice may not be removed or altered from any source distribution.
  *
- *  Version: $Id: embryo_cc_sc4.c,v 1.8 2008/04/11 19:06:18 doursse Exp $
+ *  Version: $Id: embryo_cc_sc4.c 45071 2010-01-12 22:44:25Z caro $
  */
 
 /*
@@ -32,7 +32,7 @@
 #include <assert.h>
 #include <ctype.h>
 #include <stdio.h>
-#include <stdlib.h>		/* for _MAX_PATH */
+#include <limits.h>		/* for PATH_MAX */
 #include <string.h>
 
 #include "embryo_cc_sc.h"
